@@ -6,8 +6,8 @@ from pathlib import Path
 
 from mercury_engine_data_structures.formats import Bmsad, Txt
 
+from open_dread_rando import model_data
 from open_dread_rando.lua_editor import LuaEditor
-from open_dread_rando.model_data import ALL_MODEL_DATA
 from open_dread_rando.patcher_editor import PatcherEditor, path_for_level
 
 EXPANSION_ITEM_IDS = {
@@ -81,11 +81,19 @@ class ActorPickup(BasePickup):
             set_custom_params["Param5"]["value"] = ""
             set_custom_params["Param6"]["value"] = "LIFE"
             set_custom_params["Param7"]["value"] = "#GUI_ITEM_ACQUIRED_ENERGY_SHARD"
+
+            fields = pickable["fields"]["fields"]
             caption = self.pickup["caption"]
-            pickable["fields"]["fields"]["sOnPickEnergyFragment1Caption"] = caption
-            pickable["fields"]["fields"]["sOnPickEnergyFragment2Caption"] = caption
-            pickable["fields"]["fields"]["sOnPickEnergyFragment3Caption"] = caption
-            pickable["fields"]["fields"]["sOnPickEnergyFragmentCompleteCaption"] = caption
+            if caption == "Energy Part acquired.\nCollect 4 to increase energy capacity.":
+                # If text is vanilla, then support showing how many parts we had.
+                fields["sOnPickEnergyFragment1Caption"] = "#GUI_TANK_ACQUIRED_ENERGY_FRAGMENT_1"
+                fields["sOnPickEnergyFragment2Caption"] = "#GUI_TANK_ACQUIRED_ENERGY_FRAGMENT_2"
+                fields["sOnPickEnergyFragment3Caption"] = "#GUI_TANK_ACQUIRED_ENERGY_FRAGMENT_3"
+                fields["sOnPickEnergyFragmentCompleteCaption"] = "#GUI_TANK_ACQUIRED_ENERGY_FRAGMENT_COMPLETE"
+            else:
+                for field_name in ["sOnPickEnergyFragment1Caption", "sOnPickEnergyFragment2Caption",
+                                   "sOnPickEnergyFragment3Caption", "sOnPickEnergyFragmentCompleteCaption"]:
+                    fields[field_name] = caption
 
         elif item_id in {"ITEM_WEAPON_MISSILE_MAX", "ITEM_WEAPON_POWER_BOMB_MAX", "ITEM_WEAPON_POWER_BOMB"}:
             current = item_id.replace("_MAX", "_CURRENT")
@@ -134,20 +142,23 @@ class ActorPickup(BasePickup):
         actor = level.actors_for_layer(pickup_actor["layer"])[pickup_actor["actor"]]
 
         model_name: str = self.pickup["model"]
-        model_data = ALL_MODEL_DATA.get(model_name, ALL_MODEL_DATA["itemsphere"])
+        selected_model_data = model_data.get_data(model_name)
 
         new_template = copy.deepcopy(template_bmsad)
         new_template["name"] = f"randomizer_powerup_{self.pickup_id}"
 
         # Update used model
-        new_template["property"]["model_name"] = model_data.bcmdl_path
-        MODELUPDATER = new_template["property"]["components"]["MODELUPDATER"]
-        MODELUPDATER["functions"][0]["params"]["Param1"]["value"] = model_data.bcmdl_path
+        new_template["property"]["model_name"] = selected_model_data.bcmdl_path
+        model_updater = new_template["property"]["components"]["MODELUPDATER"]
+        model_updater["functions"][0]["params"]["Param1"]["value"] = selected_model_data.bcmdl_path
 
         # Update caption
-        PICKABLE = new_template["property"]["components"]["PICKABLE"]
-        PICKABLE["fields"]["fields"]["sOnPickCaption"] = self.pickup["caption"]
-        PICKABLE["fields"]["fields"]["sOnPickTankUnknownCaption"] = self.pickup["caption"]
+        pickable = new_template["property"]["components"]["PICKABLE"]
+        pickable["fields"]["fields"]["sOnPickCaption"] = self.pickup["caption"]
+        pickable["fields"]["fields"]["sOnPickTankUnknownCaption"] = self.pickup["caption"]
+
+        # Animation/BMSAS
+        new_template["property"]["binaries"][0] = selected_model_data.bmsas
 
         # Update given item
         if len(self.pickup["resources"]) == 1:
@@ -166,7 +177,7 @@ class ActorPickup(BasePickup):
         for level_pkg in pkgs_for_level:
             editor.ensure_present(level_pkg, "system/animtrees/base.bmsat")
             editor.ensure_present(level_pkg, "actors/items/itemsphere/charclasses/timeline.bmsas")
-            for dep in model_data.dependencies:
+            for dep in selected_model_data.dependencies:
                 editor.ensure_present(level_pkg, dep)
 
         for pkg in pkgs_for_level:
@@ -216,7 +227,7 @@ class CoreXPickup(ActorDefPickup):
     def patch(self, editor: PatcherEditor):
         bmsad_path, actordef = self._patch_actordef_pickup(editor, "sInventoryItemOnBigXAbsorbed")
         editor.replace_asset(bmsad_path, actordef)
-    
+
     def _patch_actordef_pickup_script_help(self, editor: PatcherEditor):
         return self.lua_editor.patch_corex_pickup_script(
             editor,
